import typing
import collections.abc
import typing_extensions

GenericType1 = typing.TypeVar("GenericType1")
GenericType2 = typing.TypeVar("GenericType2")

def argparse_create(): ...
def call_handle_checked(fn, *, do_register, all_users): ...
def filepath_ensure_removed(path): ...
def filepath_repr(filepath): ...
def handle_bin(do_register, all_users): ...
def handle_desktop_file(do_register, all_users): ...
def handle_icon(do_register, all_users): ...
def handle_mime_association_default(do_register, all_users): ...
def handle_mime_association_xml(do_register, all_users): ...
def handle_thumbnailer(do_register, all_users): ...
def main(): ...
def main_run_as_root(do_register, *, python_args): ...
def path_exists_or_is_link(path): ...
def register(all_users=False): ...
def register_impl(do_register, all_users): ...
def system_path_contains(dirpath): ...
def unregister(all_users=False): ...
