import typing
import collections.abc
import typing_extensions
from . import external_editor as external_editor

GenericType1 = typing.TypeVar("GenericType1")
GenericType2 = typing.TypeVar("GenericType2")
